package com.audinate.gui.controller;

import com.audinate.Counter;
import com.audinate.Pair;
import com.audinate.cmm.CmmConfig;
import com.audinate.cmm.CmmInterface;
import com.audinate.cmm.ICmmClient;
import com.audinate.conmon.IConmonController;
import com.audinate.conmon.InstanceId;
import com.audinate.conmon.audinate.EnrolConfigParams;
import com.audinate.conmon.model.IConmonModel;
import com.audinate.controller.ValidationRegex;
import com.audinate.dante.DanteDomainInfo;
import com.audinate.dante.DanteDomainUuid;
import com.audinate.dante.DeviceUtils;
import com.audinate.dante.FilteredDevices;
import com.audinate.dante.IDanteDomainConstants;
import com.audinate.dante.IDanteDomainHandler;
import com.audinate.dante.IDevice;
import com.audinate.dante.IDevices;
import com.audinate.dante.IInferredInfo;
import com.audinate.dante.filters.EnrolConfigurableFilter;
import com.audinate.dante.filters.IDeviceFilter;
import com.audinate.graphql.IGraphQlController;
import com.audinate.graphql.IGraphQlModel;
import com.audinate.gui.app.ISwingApplication;
import com.audinate.gui.dante.DevicesListPane;
import com.audinate.gui.dante.HostnameDocument;
import com.audinate.gui.i18n.ILocalisable;
import com.audinate.gui.net.UnsignedShortDocument;
import com.audinate.gui.util.BasicListModel;
import com.audinate.gui.util.IconImageDialog;
import com.audinate.gui.util.RoundedPanelDecorator;
import com.audinate.gui.util.SwingUtils;
import com.audinate.model.json.JsonUpdateListener;
import com.audinate.net.INetworkInterfaceAddresses;
import com.audinate.net.IpAddress;
import com.audinate.net.IpSocketAddress;
import com.audinate.net.NetworkInterface;
import com.audinate.net.Subnets;
import com.audinate.router.IRouterController;
import com.audinate.router.model.IRouterModel;
import com.audinate.util.IObserver;
import com.audinate.util.Log;
import com.audinate.util.ResourceBundleUtils;
import com.audinate.util.SafeEquals;
import com.audinate.util.StringUtils;
import java.awt.Component;
import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.IOException;
import java.net.InetAddress;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.text.MessageFormat;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import java.util.ResourceBundle;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.CompletionException;
import java.util.stream.Collectors;
import javax.swing.AbstractAction;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ComboBoxModel;
import javax.swing.DefaultListCellRenderer;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.ListCellRenderer;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;
import javax.swing.border.EmptyBorder;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import javax.swing.text.PlainDocument;

/* loaded from: com_audinate_gui_controller.jar:com/audinate/gui/controller/EnrolmentConfigDialog.class */
public class EnrolmentConfigDialog extends IconImageDialog implements ILocalisable {
    private static final int MAX_WIDTH = 230;
    private static final IDeviceFilter IP_ENROLLABLE_FILTER = new EnrolConfigurableFilter(false);
    private static final IDeviceFilter FQDN_ENROLLABLE_FILTER = new EnrolConfigurableFilter(true);
    private static final long serialVersionUID = -3883622039028050012L;
    private static final int MODE_CONNECTED_MANAGED = 1;
    private static final int MODE_DISCONNECTED = 2;
    private static final int MODE_CONNECTED_ADHOC = 3;
    public static final int EXIT_ACTION_NONE = 0;
    public static final int EXIT_ACTION_OPEN_DOMAIN_HANDLER = 1;
    private DevicesListPane mDevicesListPane;
    private JTextField mHost;
    private JTextField mPort;
    private IConmonController mConmonController;
    private IRouterController mRouterController;
    private ICmmClient mCmmClient;
    private int mMode;
    private int mReachableTimeoutMs;
    private AbstractAction mOkAction;
    private AbstractAction mCancelAction;
    private AbstractAction mDomainLoginAction;
    private AbstractAction mToAdhocAction;
    private FilteredDevices mIpFilteredDevices;
    private JLabel mHostLabel;
    private JLabel mPortLabel;
    private JLabel mDevicesListLabel;
    private JLabel mAssignToLabel;
    private JComboBox<AssignableDomain> mAssignToField;
    private BasicComboboxModel<AssignableDomain> mAvailableDomainsModel;
    private ISwingApplication mApp;
    private ResourceBundle mBundle;
    private boolean mFqdn;
    private ListCellRendererImpl mListCellRenderer;
    private IDanteDomainHandler mHandler;
    private Comparator<AssignableDomain> mDomainNameComparator;
    private IObserver mHandlerObserver;
    private JButton mOkButton;
    private JButton mCancelButton;
    private JLabel mPleaseLoginLabel;
    private JButton mDomainLoginButton;
    private JLabel mManualModeLink;
    private JLabel mOnlyUnmanagedLabel;
    private JButton mToAdhocButton;
    private JLabel mUsePortalLabel;
    private int mExitAction;
    private boolean mManualModel;
    private String mConfigSentTemplate;
    private String mAssignedDomainTemplate;
    private String mAssignedDomainErrorTemplate;
    private IGraphQlController mGraphQlController;
    private IGraphQlModel mGraphQlModel;
    private Box mInnerPane;
    private JsonUpdateListener mGraphQLModelListener;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_audinate_gui_controller.jar:com/audinate/gui/controller/EnrolmentConfigDialog$AssignableDomain.class */
    public final class AssignableDomain extends Pair<String, DanteDomainUuid> {
        public AssignableDomain(String str, DanteDomainUuid danteDomainUuid) {
            super(str, danteDomainUuid);
        }

        public String toString() {
            return (String) super.getFirst();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_audinate_gui_controller.jar:com/audinate/gui/controller/EnrolmentConfigDialog$BasicComboboxModel.class */
    public class BasicComboboxModel<E> extends BasicListModel<E> implements ComboBoxModel<E> {
        private Object mSelectedObject = null;

        private BasicComboboxModel() {
        }

        public void setSelectedItem(Object obj) {
            this.mSelectedObject = obj;
            fireContentsChanged(this, -1, -1);
        }

        public Object getSelectedItem() {
            return this.mSelectedObject;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: com_audinate_gui_controller.jar:com/audinate/gui/controller/EnrolmentConfigDialog$ListCellRendererImpl.class */
    public final class ListCellRendererImpl implements ListCellRenderer<IDevice>, ILocalisable {
        private DefaultListCellRenderer mDelegate = new DefaultListCellRenderer();
        private String mIpOnlyTooltip;

        private ListCellRendererImpl() {
        }

        public Component getListCellRendererComponent(JList<? extends IDevice> jList, IDevice iDevice, int i, boolean z, boolean z2) {
            this.mDelegate.getListCellRendererComponent(jList, iDevice.getName(), i, z, z2);
            if (!EnrolmentConfigDialog.this.mFqdn || EnrolmentConfigDialog.FQDN_ENROLLABLE_FILTER.matches(iDevice)) {
                this.mDelegate.setToolTipText((String) null);
            } else {
                this.mDelegate.setToolTipText(this.mIpOnlyTooltip);
            }
            return this.mDelegate;
        }

        public void localise(ResourceBundle resourceBundle) {
            this.mIpOnlyTooltip = ResourceBundleUtils.getString(resourceBundle, "domainEnrol.ipOnlyTooltip");
        }

        public /* bridge */ /* synthetic */ Component getListCellRendererComponent(JList jList, Object obj, int i, boolean z, boolean z2) {
            return getListCellRendererComponent((JList<? extends IDevice>) jList, (IDevice) obj, i, z, z2);
        }
    }

    private boolean isLinkLocal(IpAddress ipAddress) {
        return ipAddress.inSubnet(new IpAddress(new int[]{169, 254, 0, 0}), new IpAddress(new int[]{255, 255, 0, 0}));
    }

    private boolean isReachable(IpAddress ipAddress, int i) {
        try {
            CmmConfig currentConfig = this.mCmmClient.getSystemState().getCurrentConfig();
            CmmInterface interfaceAtIndex = currentConfig.numInterfaces() > 0 ? currentConfig.interfaceAtIndex(0) : null;
            if (interfaceAtIndex == null) {
                return false;
            }
            NetworkInterface interfaceWithName = this.mApp.getNetworkInterfaceManager().interfaceWithName(interfaceAtIndex.getName());
            try {
                try {
                    Socket socket = new Socket();
                    try {
                        socket.bind(new InetSocketAddress(interfaceWithName.getIpAddress().toString(), 0));
                        socket.connect(new InetSocketAddress(ipAddress.toString(), i), this.mReachableTimeoutMs);
                        socket.close();
                        return true;
                    } catch (Throwable th) {
                        try {
                            socket.close();
                        } catch (Throwable th2) {
                            th.addSuppressed(th2);
                        }
                        throw th;
                    }
                } catch (Exception e) {
                    System.out.println("Error: " + e.getMessage());
                    return false;
                }
            } catch (IOException e2) {
                System.out.println("Socket I/O Error: " + e2.getMessage());
                return false;
            }
        } catch (Exception e3) {
            System.out.println("Error: " + e3.getMessage());
            return false;
        }
    }

    /* JADX WARN: Failed to find 'out' block for switch in B:38:0x00f7. Please report as an issue. */
    private void updateAssignableDomains() {
        ArrayList arrayList = new ArrayList();
        if (this.mHandler == null) {
            this.mAvailableDomainsModel.clear();
            this.mAvailableDomainsModel.setSelectedItem(null);
            return;
        }
        for (int i = 0; i < this.mHandler.numDomains(); i++) {
            DanteDomainUuid uuid = this.mHandler.domainAtIndex(i).getUuid();
            if (!uuid.equals(IDanteDomainConstants.DOMAIN_UUID_NONE) && !uuid.equals(IDanteDomainConstants.DOMAIN_UUID_ADHOC)) {
                DanteDomainInfo domainWithUuid = this.mHandler != null ? this.mHandler.domainWithUuid(uuid) : null;
                if (domainWithUuid != null && domainWithUuid.getCapabilities().canEnrolDevices()) {
                    arrayList.add(new AssignableDomain(domainWithUuid.getName(), uuid));
                }
            }
        }
        Collections.sort(arrayList, this.mDomainNameComparator);
        BasicListModel basicListModel = this.mAvailableDomainsModel;
        int i2 = 0;
        int i3 = 0;
        AssignableDomain assignableDomain = 0 < basicListModel.size() ? (AssignableDomain) basicListModel.get(0) : null;
        AssignableDomain assignableDomain2 = 0 < arrayList.size() ? (AssignableDomain) arrayList.get(0) : null;
        while (i2 < basicListModel.size() && i3 < arrayList.size()) {
            switch (Integer.signum(this.mDomainNameComparator.compare(assignableDomain, assignableDomain2))) {
                case -1:
                    basicListModel.remove(i2);
                    break;
                case EXIT_ACTION_NONE /* 0 */:
                    i2++;
                    i3++;
                    assignableDomain2 = i3 < arrayList.size() ? (AssignableDomain) arrayList.get(i3) : null;
                    break;
                case 1:
                    basicListModel.add(i2, assignableDomain2);
                    i2++;
                    i3++;
                    assignableDomain2 = i3 < arrayList.size() ? (AssignableDomain) arrayList.get(i3) : null;
                    break;
            }
            assignableDomain = i2 < basicListModel.size() ? (AssignableDomain) basicListModel.get(i2) : null;
        }
        while (i2 < basicListModel.size()) {
            basicListModel.remove(i2);
        }
        while (i3 < arrayList.size()) {
            basicListModel.add(assignableDomain2);
            i3++;
            assignableDomain2 = i3 < arrayList.size() ? (AssignableDomain) arrayList.get(i3) : null;
        }
        if (this.mAvailableDomainsModel.size() <= 0) {
            this.mAvailableDomainsModel.setSelectedItem(null);
        } else {
            if (this.mAvailableDomainsModel.getSelectedItem() == null || this.mAvailableDomainsModel.contains(this.mAvailableDomainsModel.getSelectedItem())) {
                return;
            }
            this.mAvailableDomainsModel.setSelectedItem(this.mAvailableDomainsModel.get(0));
        }
    }

    public EnrolmentConfigDialog(ISwingApplication iSwingApplication, JFrame jFrame) {
        super(jFrame);
        this.mHost = new JTextField();
        this.mPort = new JTextField();
        this.mMode = MODE_DISCONNECTED;
        this.mReachableTimeoutMs = 3000;
        this.mOkAction = new AbstractAction() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.1
            private static final long serialVersionUID = 1;

            public void actionPerformed(ActionEvent actionEvent) {
                IpAddress parse;
                try {
                    int parseInt = Integer.parseInt(EnrolmentConfigDialog.this.mPort.getText().trim());
                    IDevice[] selectedDevices = EnrolmentConfigDialog.this.mDevicesListPane.getSelectedDevices();
                    if (selectedDevices == null || selectedDevices.length == 0) {
                        return;
                    }
                    String text = EnrolmentConfigDialog.this.mHost.getText();
                    if (text.endsWith(".")) {
                        text = text.substring(0, text.length() - 1);
                    }
                    String str = null;
                    if (ValidationRegex.IP_V4_PATTERN.matcher(text).matches()) {
                        try {
                            parse = IpAddress.parse(text);
                        } catch (ParseException e) {
                            e.printStackTrace();
                            EnrolmentConfigDialog.this.showError("Failed to parse IP Address");
                            return;
                        }
                    } else {
                        str = text;
                        try {
                            parse = IpAddress.parse(InetAddress.getByName(text).getHostAddress());
                        } catch (Exception e2) {
                            EnrolmentConfigDialog.this.mApp.getDialogs().showError(EnrolmentConfigDialog.this, ResourceBundleUtils.getString(EnrolmentConfigDialog.this.mBundle, "domainEnrol.couldNotResolve"));
                            return;
                        }
                    }
                    boolean z = false;
                    try {
                        Iterator it = Arrays.asList(selectedDevices).iterator();
                        while (true) {
                            if (!it.hasNext()) {
                                break;
                            }
                            String ipAddress = getIpAddress((IDevice) it.next());
                            if (ipAddress != null && EnrolmentConfigDialog.this.isLinkLocal(IpAddress.parse(ipAddress))) {
                                z = true;
                                break;
                            }
                        }
                    } catch (Exception e3) {
                        System.out.println("Error: " + e3.toString());
                    }
                    if (z) {
                        EnrolmentConfigDialog.this.showError(ResourceBundleUtils.getString(EnrolmentConfigDialog.this.mBundle, "domainEnrol.linkLocalDeviceWarning.message"));
                        return;
                    }
                    if (!EnrolmentConfigDialog.this.mManualModel && !EnrolmentConfigDialog.this.isReachable(parse, EnrolmentConfigDialog.this.mHandler.getDdmAddress().getPort())) {
                        EnrolmentConfigReachableDialog enrolmentConfigReachableDialog = new EnrolmentConfigReachableDialog(EnrolmentConfigDialog.this, EnrolmentConfigDialog.this.mApp);
                        enrolmentConfigReachableDialog.setModal(true);
                        enrolmentConfigReachableDialog.setLocationRelativeTo(EnrolmentConfigDialog.this.getParent());
                        enrolmentConfigReachableDialog.setVisible(true);
                        if (!enrolmentConfigReachableDialog.getResult()) {
                            return;
                        }
                    }
                    if (EnrolmentConfigDialog.this.mConmonController != null && EnrolmentConfigDialog.this.mRouterController != null) {
                        List<IDevice> asList = Arrays.asList(selectedDevices);
                        for (IDevice iDevice : asList) {
                            if (str == null || !EnrolmentConfigDialog.FQDN_ENROLLABLE_FILTER.matches(iDevice)) {
                                EnrolmentConfigDialog.this.mConmonController.setEnrolConfig(iDevice.getName(), new EnrolConfigParams((String) null, parse, parseInt));
                            } else {
                                EnrolmentConfigDialog.this.mConmonController.setEnrolConfig(iDevice.getName(), new EnrolConfigParams(str, parse, parseInt));
                            }
                        }
                        AssignableDomain assignableDomain = null;
                        if (EnrolmentConfigDialog.this.mAssignToField.isVisible() && EnrolmentConfigDialog.this.mAssignToField.getSelectedItem() != null) {
                            AssignableDomain assignableDomain2 = (AssignableDomain) EnrolmentConfigDialog.this.mAssignToField.getSelectedItem();
                            if (assignableDomain2.getSecond() != null) {
                                assignableDomain = assignableDomain2;
                            }
                        }
                        if (assignableDomain != null) {
                            String str2 = (String) assignableDomain.getFirst();
                            String lowerCase = ((DanteDomainUuid) assignableDomain.getSecond()).toString().toLowerCase();
                            List<IGraphQlController.PendingEnrolmentRequest> list = (List) asList.stream().map(iDevice2 -> {
                                return deviceToRequestData(iDevice2);
                            }).collect(Collectors.toList());
                            CompletableFuture completedFuture = CompletableFuture.completedFuture(null);
                            Counter counter = new Counter(0);
                            for (IGraphQlController.PendingEnrolmentRequest pendingEnrolmentRequest : list) {
                                completedFuture = completedFuture.thenComposeAsync(r11 -> {
                                    CompletableFuture completableFuture = new CompletableFuture();
                                    EnrolmentConfigDialog.this.mGraphQlController.addPendingEnrolment(EnrolmentConfigDialog.this.mGraphQlModel.getSchema(), pendingEnrolmentRequest, lowerCase, EnrolmentConfigDialog.this.mBundle).whenComplete((str3, th) -> {
                                        if (th != null) {
                                            completableFuture.completeExceptionally(th);
                                            return;
                                        }
                                        if (str3 != null) {
                                            String name = ((IGraphQlController.PendingEnrolmentRequest) list.get(counter.getValue())).getName();
                                            SwingUtilities.invokeLater(() -> {
                                                EnrolmentConfigDialog.this.mRouterController.renameDevice(name, str3);
                                            });
                                        }
                                        counter.inc();
                                        completableFuture.complete(null);
                                    });
                                    return completableFuture;
                                });
                            }
                            completedFuture.whenComplete((r112, th) -> {
                                if (th == null) {
                                    SwingUtilities.invokeLater(() -> {
                                        EnrolmentConfigDialog.this.mApp.getDialogs().showMessage(EnrolmentConfigDialog.this, MessageFormat.format(EnrolmentConfigDialog.this.mAssignedDomainTemplate, Integer.valueOf(counter.getValue()), str2));
                                    });
                                    return;
                                }
                                String exceptionMessage = getExceptionMessage(th);
                                String name = ((IGraphQlController.PendingEnrolmentRequest) list.get(counter.getValue())).getName();
                                SwingUtilities.invokeLater(() -> {
                                    EnrolmentConfigDialog.this.mApp.getDialogs().showMessage(EnrolmentConfigDialog.this, MessageFormat.format(EnrolmentConfigDialog.this.mAssignedDomainErrorTemplate, Integer.valueOf(counter.getValue()), Integer.valueOf(list.size()), str2, name, exceptionMessage));
                                });
                            });
                        } else {
                            EnrolmentConfigDialog.this.mApp.getDialogs().showMessage(EnrolmentConfigDialog.this, MessageFormat.format(EnrolmentConfigDialog.this.mConfigSentTemplate, Integer.valueOf(selectedDevices.length)));
                        }
                    }
                    EnrolmentConfigDialog.this.setVisible(false);
                } catch (NumberFormatException e4) {
                    e4.printStackTrace();
                    EnrolmentConfigDialog.this.showError("Invalid port");
                }
            }

            private String getExceptionMessage(Throwable th) {
                Throwable th2 = th;
                String message = th2.getMessage();
                while (th2 instanceof CompletionException) {
                    th2 = th2.getCause();
                    if (th2 != null) {
                        message = th2.getMessage();
                    }
                }
                return message;
            }

            private boolean isIpAddressValid(IpAddress ipAddress) {
                return (Subnets.THIS_NETWORK.contains(ipAddress) || Subnets.LOCALHOST.contains(ipAddress) || Subnets.MULTICAST.contains(ipAddress) || Subnets.FUTURE_USE.contains(ipAddress) || ipAddress.isLocalBroadcast() || ipAddress == null) ? false : true;
            }

            private String getIpAddress(IDevice iDevice) {
                IConmonModel.IInterfaces componentAtIndex;
                IConmonModel.IInterfaces.IInterface interfaceAtIndex;
                INetworkInterfaceAddresses addresses;
                IpSocketAddress[] addresses2;
                IRouterModel routerModel = DeviceUtils.getRouterModel(iDevice);
                if (routerModel != null && (addresses2 = routerModel.getAddresses()) != null && addresses2.length > 0) {
                    IpAddress host = addresses2[0].getHost();
                    if (isIpAddressValid(host)) {
                        return host.toString();
                    }
                }
                IConmonModel conmonModel = DeviceUtils.getConmonModel(iDevice);
                if (conmonModel != null && (componentAtIndex = conmonModel.componentAtIndex(1)) != null) {
                    for (int i = 0; i < componentAtIndex.numInterfaces() && (interfaceAtIndex = componentAtIndex.interfaceAtIndex(i)) != null && (addresses = interfaceAtIndex.getAddresses()) != null; i++) {
                        IpAddress ipAddress = addresses.getIpAddress();
                        if (isIpAddressValid(ipAddress)) {
                            return ipAddress.toString();
                        }
                    }
                }
                IInferredInfo inferredInfo = iDevice.getInferredInfo();
                if (inferredInfo == null || inferredInfo.numNetworks() <= 0) {
                    return null;
                }
                IpAddress ipAddress2 = inferredInfo.networkAtIndex(0).getIpAddress();
                if (isIpAddressValid(ipAddress2)) {
                    return ipAddress2.toString();
                }
                return null;
            }

            private IGraphQlController.PendingEnrolmentRequest deviceToRequestData(IDevice iDevice) {
                InstanceId instanceId = iDevice.getInstanceId();
                return new IGraphQlController.PendingEnrolmentRequest(iDevice.getName(), StringUtils.toHexString(instanceId.getDeviceIdBytes(), (String) null).toLowerCase() + ":" + instanceId.getProcessId(), getIpAddress(iDevice));
            }
        };
        this.mCancelAction = new AbstractAction() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.2
            private static final long serialVersionUID = 1;

            public void actionPerformed(ActionEvent actionEvent) {
                EnrolmentConfigDialog.this.setVisible(false);
            }
        };
        this.mDomainLoginAction = new AbstractAction() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.3
            private static final long serialVersionUID = 1;

            public void actionPerformed(ActionEvent actionEvent) {
                EnrolmentConfigDialog.this.mExitAction = 1;
                EnrolmentConfigDialog.this.setVisible(false);
            }
        };
        this.mToAdhocAction = new AbstractAction() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.4
            private static final long serialVersionUID = 1;

            public void actionPerformed(ActionEvent actionEvent) {
                if (EnrolmentConfigDialog.this.mHandler != null) {
                    EnrolmentConfigDialog.this.mHandler.setActiveDomain(IDanteDomainConstants.DOMAIN_UUID_ADHOC);
                }
            }
        };
        this.mAvailableDomainsModel = new BasicComboboxModel<>();
        this.mFqdn = false;
        this.mDomainNameComparator = new Comparator<AssignableDomain>() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.5
            @Override // java.util.Comparator
            public int compare(AssignableDomain assignableDomain, AssignableDomain assignableDomain2) {
                if (assignableDomain2.getSecond() == null && assignableDomain.getSecond() == null) {
                    return 0;
                }
                if (assignableDomain.getSecond() == null) {
                    return 1;
                }
                if (assignableDomain2.getSecond() == null) {
                    return -1;
                }
                return ((String) assignableDomain.getFirst()).compareToIgnoreCase((String) assignableDomain2.getFirst());
            }
        };
        this.mHandlerObserver = (iObservable, obj) -> {
            Integer num = (Integer) obj;
            boolean z = (num.intValue() & 1) != 0;
            boolean z2 = (num.intValue() & MODE_DISCONNECTED) != 0;
            boolean z3 = (num.intValue() & 4) != 0;
            if (z2 || z) {
                if (this.mHandler.getState() != 6) {
                    setMode(MODE_DISCONNECTED);
                } else if (this.mHandler.getActiveUuid().isManagedDomain()) {
                    setMode(1);
                } else {
                    if (this.mMode != MODE_CONNECTED_ADHOC) {
                        setHostname(this.mHandler.getDdmAddress().getHostname());
                        setPort(this.mHandler.getDevicePort());
                    }
                    setMode(MODE_CONNECTED_ADHOC);
                }
            }
            if (z3) {
                updateAssignableDomains();
            }
        };
        this.mPleaseLoginLabel = new JLabel("", 0);
        this.mDomainLoginButton = new JButton(this.mDomainLoginAction);
        this.mManualModeLink = new JLabel("", 0);
        this.mOnlyUnmanagedLabel = new JLabel("", 0);
        this.mToAdhocButton = new JButton(this.mToAdhocAction);
        this.mUsePortalLabel = new JLabel("", 0);
        this.mExitAction = 0;
        this.mManualModel = false;
        this.mGraphQLModelListener = jsonUpdateEvent -> {
            if (jsonUpdateEvent.getPath().isEmpty() || !"schema".equals(jsonUpdateEvent.getPath().get(0))) {
                return;
            }
            layoutComponents(true);
        };
        this.mApp = iSwingApplication;
        this.mIpFilteredDevices = new FilteredDevices((Log) null);
        this.mIpFilteredDevices.setFilter(IP_ENROLLABLE_FILTER);
        this.mListCellRenderer = new ListCellRendererImpl();
        this.mDevicesListPane = new DevicesListPane(this.mListCellRenderer);
        this.mDevicesListPane.setDevices(this.mIpFilteredDevices);
        this.mDevicesListPane.setEnabled(false);
        this.mDevicesListPane.mListScrollPane.setMinimumSize(new Dimension(400, 120));
        this.mDevicesListPane.mListScrollPane.setPreferredSize(new Dimension(400, 120));
        this.mDevicesListPane.mListScrollPane.setMaximumSize(new Dimension(400, 120));
        this.mDevicesListPane.addListSelectionListener(new ListSelectionListener() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.6
            public void valueChanged(ListSelectionEvent listSelectionEvent) {
                EnrolmentConfigDialog.this.updateOkAction();
            }
        });
        this.mHost.addFocusListener(new FocusAdapter() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.7
            public void focusLost(FocusEvent focusEvent) {
                EnrolmentConfigDialog.this.validateHostname();
                EnrolmentConfigDialog.this.updateOkAction();
            }
        });
        this.mPort.addFocusListener(new FocusAdapter() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.8
            public void focusLost(FocusEvent focusEvent) {
                EnrolmentConfigDialog.this.updateOkAction();
            }
        });
        this.mPort.setText("8000");
        this.mHostLabel = new JLabel();
        this.mPortLabel = new JLabel();
        this.mDevicesListLabel = new JLabel();
        this.mDevicesListLabel.setBorder(new EmptyBorder(12, 0, 12, 0));
        this.mAssignToLabel = new JLabel();
        this.mAssignToField = new JComboBox<>(this.mAvailableDomainsModel);
        this.mOkButton = new JButton(this.mOkAction);
        this.mOkButton.setMinimumSize(new Dimension(128, 32));
        this.mOkButton.setPreferredSize(new Dimension(128, 32));
        this.mOkButton.setMaximumSize(new Dimension(128, 32));
        this.mCancelButton = new JButton(this.mCancelAction);
        this.mCancelButton.setMinimumSize(new Dimension(128, 32));
        this.mCancelButton.setPreferredSize(new Dimension(128, 32));
        this.mCancelButton.setMaximumSize(new Dimension(128, 32));
        this.mManualModeLink.addMouseListener(new MouseAdapter() { // from class: com.audinate.gui.controller.EnrolmentConfigDialog.9
            public void mouseClicked(MouseEvent mouseEvent) {
                EnrolmentConfigDialog.this.setManualMode(true);
            }
        });
        this.mManualModeLink.setCursor(Cursor.getPredefinedCursor(12));
        localise(this.mApp != null ? this.mApp.getSwingConfig().getStringsBundle() : null, true);
        validateHostname();
        updateOkAction();
    }

    public void setVisible(boolean z) {
        if (z) {
            setManualMode(false);
            clearExitAction();
            layoutComponents(true);
            if (this.mAvailableDomainsModel.size() <= 0) {
                this.mAvailableDomainsModel.setSelectedItem(null);
            } else if (this.mAvailableDomainsModel.getSelectedItem() == null || !this.mAvailableDomainsModel.contains(this.mAvailableDomainsModel.getSelectedItem())) {
                this.mAvailableDomainsModel.setSelectedItem(this.mAvailableDomainsModel.get(0));
            }
        }
        super.setVisible(z);
    }

    public void dispose() {
        setDomainHandler(null);
        super.dispose();
    }

    public void setDialogSelectedDomain(String str) {
        if (str != null) {
            int i = -1;
            for (int i2 = 0; i == -1 && i2 < this.mAvailableDomainsModel.size(); i2++) {
                if (SafeEquals.safeEquals(((DanteDomainUuid) ((AssignableDomain) this.mAvailableDomainsModel.get(i2)).getSecond()).toString().toLowerCase(), str.toLowerCase())) {
                    i = i2;
                }
            }
            if (i != -1) {
                this.mAvailableDomainsModel.setSelectedItem(this.mAvailableDomainsModel.get(i));
            }
        }
    }

    private void setMode(int i) {
        if (this.mMode != i) {
            this.mMode = i;
            layoutComponents(false);
        }
    }

    void setDomainHandler(IDanteDomainHandler iDanteDomainHandler) {
        if (this.mHandler != null) {
            this.mHandler.removeObserver(this.mHandlerObserver);
            this.mHandler = null;
        }
        if (iDanteDomainHandler != null) {
            this.mHandler = iDanteDomainHandler;
            this.mHandler.addObserver(this.mHandlerObserver);
            this.mHandlerObserver.update(this.mHandler, 7);
        }
    }

    private void validateHostname() {
        if (ValidationRegex.HOSTNAME_PATTERN.matcher(this.mHost.getText()).matches()) {
            setFqdn(!ValidationRegex.IP_V4_PATTERN.matcher(this.mHost.getText()).matches());
        }
    }

    private boolean isValidHostname() {
        return ValidationRegex.HOSTNAME_PATTERN.matcher(this.mHost.getText()).matches();
    }

    private boolean isValidPort() {
        return ValidationRegex.UINT16_PATTERN.matcher(this.mPort.getText()).matches();
    }

    private void updateOkAction() {
        this.mOkAction.setEnabled(isValidHostname() && isValidPort() && !this.mDevicesListPane.isSelectionEmpty());
    }

    private void showError(String str) {
        if (this.mApp != null) {
            this.mApp.getDialogs().showError(this, str);
        }
    }

    private void setFqdn(boolean z) {
        if (this.mFqdn != z) {
            this.mFqdn = z;
            this.mDevicesListPane.repaint();
        }
    }

    protected void layoutComponents(boolean z) {
        if (z || isVisible()) {
            if (this.mInnerPane != null) {
                remove(this.mInnerPane);
            }
            this.mInnerPane = new Box(1);
            this.mAssignToField.setVisible(this.mMode == MODE_CONNECTED_ADHOC);
            this.mAssignToLabel.setVisible(this.mMode == MODE_CONNECTED_ADHOC);
            setLayout(new GridBagLayout());
            SwingUtils.add(this, this.mInnerPane, 0, 0, 1, 1, 1.0d, 1.0d, 11, MODE_DISCONNECTED, new Insets(16, 16, 16, 16));
            if (this.mMode == 1) {
                this.mHost.setMinimumSize((Dimension) null);
                this.mPort.setPreferredSize((Dimension) null);
                String text = this.mHost.getText();
                String text2 = this.mPort.getText();
                this.mHost.setDocument(new PlainDocument());
                this.mPort.setDocument(new PlainDocument());
                setFieldsEditable(this.mManualModel);
                setResizable(true);
                this.mHost.setMinimumSize(new Dimension(277, 32));
                this.mHost.setPreferredSize(new Dimension(277, 32));
                this.mHost.setMaximumSize(new Dimension(277, 32));
                this.mPort.setMinimumSize(new Dimension(64, 32));
                this.mPort.setPreferredSize(new Dimension(64, 32));
                this.mPort.setMaximumSize(new Dimension(64, 32));
                this.mHost.setDocument(new HostnameDocument());
                this.mPort.setDocument(new UnsignedShortDocument());
                this.mHost.setText(text);
                this.mPort.setText(text2);
                layoutForManaged();
            } else if (this.mManualModel || this.mMode == MODE_CONNECTED_ADHOC) {
                layoutForDeviceSelection();
            } else if (this.mMode == MODE_DISCONNECTED) {
                layoutForDisconnected();
            }
            pack();
            setLocationRelativeTo(getParent());
        }
    }

    private void layoutForManaged() {
        setMinimumSize(new Dimension(368, 280));
        setPreferredSize(new Dimension(368, 280));
        setMaximumSize(new Dimension(368, 280));
        this.mToAdhocButton.setMinimumSize(new Dimension(320, 32));
        this.mToAdhocButton.setPreferredSize(new Dimension(320, 32));
        this.mToAdhocButton.setMaximumSize(new Dimension(320, 32));
        this.mInnerPane.removeAll();
        JPanel jPanel = new JPanel(new GridBagLayout());
        SwingUtils.add(jPanel, this.mOnlyUnmanagedLabel, 0, 1, 1, 1, 1.0d, 1.0d, 10, 0, new Insets(0, 0, 16, 0));
        SwingUtils.add(jPanel, this.mToAdhocButton, 0, MODE_DISCONNECTED, 1, 1, 1.0d, 1.0d, 10, 0, new Insets(0, 0, 16, 0));
        SwingUtils.add(jPanel, this.mUsePortalLabel, 0, MODE_CONNECTED_ADHOC, 1, 1, 1.0d, 1.0d, 10, 0, new Insets(0, 0, 16, 0));
        SwingUtils.add(jPanel, this.mCancelButton, 0, 4, 1, 1, 1.0d, 1.0d, 10, 0);
        this.mInnerPane.add(jPanel);
        this.mInnerPane.revalidate();
        this.mInnerPane.repaint();
    }

    private void layoutForDisconnected() {
        setMinimumSize(new Dimension(368, 260));
        setPreferredSize(new Dimension(368, 260));
        setMaximumSize(new Dimension(368, 260));
        this.mDomainLoginButton.setMinimumSize(new Dimension(320, 32));
        this.mDomainLoginButton.setPreferredSize(new Dimension(320, 32));
        this.mDomainLoginButton.setMaximumSize(new Dimension(320, 32));
        this.mInnerPane.removeAll();
        JPanel jPanel = new JPanel(new GridBagLayout());
        SwingUtils.add(jPanel, this.mPleaseLoginLabel, 0, 1, 1, 1, 1.0d, 1.0d, 10, 0, new Insets(0, 0, 16, 0));
        SwingUtils.add(jPanel, this.mDomainLoginButton, 0, MODE_DISCONNECTED, 1, 1, 1.0d, 1.0d, 10, 0, new Insets(0, 0, 16, 0));
        SwingUtils.add(jPanel, this.mManualModeLink, 0, MODE_CONNECTED_ADHOC, 1, 1, 1.0d, 1.0d, 10, 0, new Insets(0, 0, 16, 0));
        SwingUtils.add(jPanel, this.mCancelButton, 0, 4, 1, 1, 1.0d, 1.0d, 10, 0);
        this.mInnerPane.add(jPanel);
        this.mInnerPane.revalidate();
        this.mInnerPane.repaint();
    }

    private void layoutForDeviceSelection() {
        setMinimumSize(new Dimension(485, 650));
        setPreferredSize(new Dimension(485, 650));
        setMaximumSize(new Dimension(485, 650));
        this.mInnerPane.removeAll();
        JPanel jPanel = new JPanel(new GridBagLayout());
        jPanel.setBackground(UIManager.getColor("TitlePane.background"));
        RoundedPanelDecorator roundedPanelDecorator = new RoundedPanelDecorator(jPanel);
        roundedPanelDecorator.setInsets(new Insets(22, 48, 32, 48));
        SwingUtils.add(jPanel, this.mHostLabel, 0, 0, 1, 1, 1.0d, 1.0d, 11, MODE_DISCONNECTED, new Insets(0, 0, 4, 0));
        SwingUtils.add(jPanel, this.mHost, 0, 1, 1, 1, 1.0d, 1.0d, 11, MODE_DISCONNECTED, new Insets(0, 0, 20, 12));
        SwingUtils.add(jPanel, this.mPortLabel, 1, 0, 1, 1, 1.0d, 1.0d, 11, MODE_DISCONNECTED, new Insets(0, 0, 4, 0));
        SwingUtils.add(jPanel, this.mPort, 1, 1, 1, 1, 1.0d, 1.0d, 11, MODE_DISCONNECTED);
        SwingUtils.add(jPanel, this.mAssignToLabel, 0, MODE_DISCONNECTED, MODE_DISCONNECTED, 1, 1.0d, 1.0d, 11, MODE_DISCONNECTED, new Insets(0, 0, 4, 0));
        SwingUtils.add(jPanel, this.mAssignToField, 0, MODE_CONNECTED_ADHOC, MODE_DISCONNECTED, 1, 1.0d, 1.0d, 11, MODE_DISCONNECTED);
        this.mInnerPane.add(roundedPanelDecorator);
        JPanel jPanel2 = new JPanel(new GridBagLayout());
        SwingUtils.add(jPanel2, this.mDevicesListLabel, 0, 0, 1, 1, 1.0d, 0.0d, 18, MODE_DISCONNECTED);
        SwingUtils.add(jPanel2, this.mDevicesListPane, 0, 1, 1, 1, 1.0d, 1.0d, 18, 1);
        this.mInnerPane.add(jPanel2);
        JPanel jPanel3 = new JPanel();
        jPanel3.setLayout(new BoxLayout(jPanel3, 0));
        jPanel3.add(this.mOkButton);
        jPanel3.add(Box.createRigidArea(new Dimension(16, 0)));
        jPanel3.add(this.mCancelButton);
        jPanel3.setBorder(new EmptyBorder(32, 0, 32, 0));
        this.mInnerPane.add(jPanel3);
        this.mInnerPane.revalidate();
        this.mInnerPane.repaint();
    }

    public static void main(String[] strArr) {
        EnrolmentConfigDialog enrolmentConfigDialog = new EnrolmentConfigDialog(null, null);
        enrolmentConfigDialog.setDefaultCloseOperation(MODE_DISCONNECTED);
        enrolmentConfigDialog.setModal(true);
        enrolmentConfigDialog.setLocationRelativeTo(null);
        enrolmentConfigDialog.setVisible(true);
        System.exit(0);
    }

    public void setConmonController(IConmonController iConmonController) {
        this.mConmonController = iConmonController;
    }

    public void setRouterController(IRouterController iRouterController) {
        this.mRouterController = iRouterController;
    }

    public void setDevices(IDevices iDevices) {
        this.mIpFilteredDevices.setDevices(iDevices);
    }

    public void setCmmClient(ICmmClient iCmmClient) {
        this.mCmmClient = iCmmClient;
    }

    public void localise(ResourceBundle resourceBundle) {
        localise(resourceBundle, false);
    }

    public void localise(ResourceBundle resourceBundle, boolean z) {
        if (z || this.mBundle != resourceBundle) {
            this.mBundle = resourceBundle;
            setTitle(ResourceBundleUtils.getString(this.mBundle, "domainEnrol.title"));
            this.mOkAction.putValue("Name", ResourceBundleUtils.getString(this.mBundle, "ok"));
            this.mCancelAction.putValue("Name", ResourceBundleUtils.getString(this.mBundle, "cancel"));
            this.mHostLabel.setText(ResourceBundleUtils.getString(this.mBundle, "domainHandler.hostLabel"));
            this.mPortLabel.setText(ResourceBundleUtils.getString(this.mBundle, "domainHandler.portLabel"));
            this.mAssignToLabel.setText(ResourceBundleUtils.getString(this.mBundle, "domainEnrol.assignToLabel"));
            this.mDevicesListLabel.setText(ResourceBundleUtils.getString(this.mBundle, "domainEnrol.deviceListLabel"));
            this.mDevicesListPane.localise(this.mBundle);
            this.mListCellRenderer.localise(this.mBundle);
            this.mPleaseLoginLabel.setText(centeredWrappingText(ResourceBundleUtils.getString(this.mBundle, "domainEnrol.pleaseLogin")));
            this.mDomainLoginAction.putValue("Name", ResourceBundleUtils.getString(this.mBundle, "domainHandler.title"));
            this.mManualModeLink.setText(centeredWrappingLink(ResourceBundleUtils.getString(this.mBundle, "domainEnrol.manualMode")));
            this.mOnlyUnmanagedLabel.setText(centeredWrappingText(ResourceBundleUtils.getString(this.mBundle, "domainEnrol.onlyUnmanaged")));
            this.mToAdhocAction.putValue("Name", ResourceBundleUtils.getString(this.mBundle, "domainEnrol.toUnmanaged"));
            this.mUsePortalLabel.setText(centeredWrappingText(ResourceBundleUtils.getString(this.mBundle, "domainEnrol.usePortal")));
            this.mConfigSentTemplate = ResourceBundleUtils.getString(this.mBundle, "domainEnrol.configSent");
            this.mAssignedDomainTemplate = ResourceBundleUtils.getString(this.mBundle, "domainEnrol.assignedDomain");
            this.mAssignedDomainErrorTemplate = ResourceBundleUtils.getString(this.mBundle, "domainEnrol.assignedDomainErrorExt");
            updateAssignableDomains();
            layoutComponents(false);
        }
    }

    private String centeredWrappingText(String str) {
        return "<html><center style=\"width:230px;\">" + str + "</center><html>";
    }

    private String centeredWrappingLink(String str) {
        return "<html><a style=\"text-align:center;width:230px;\" href=\"#\">" + str + "</a><html>";
    }

    private void setHostname(String str) {
        this.mHost.setText(str);
        validateHostname();
        updateOkAction();
    }

    private void setPort(int i) {
        this.mPort.setText(Integer.toString(i));
        updateOkAction();
    }

    private void setFieldsEditable(boolean z) {
        this.mHost.setEditable(z);
        this.mPort.setEditable(z);
    }

    public int getExitAction() {
        return this.mExitAction;
    }

    public void clearExitAction() {
        this.mExitAction = 0;
    }

    private void setManualMode(boolean z) {
        if (this.mManualModel != z) {
            this.mManualModel = z;
            layoutComponents(false);
        }
    }

    public void setGraphQlController(IGraphQlController iGraphQlController) {
        this.mGraphQlController = iGraphQlController;
    }

    public void setGraphQlModel(IGraphQlModel iGraphQlModel) {
        if (this.mGraphQlModel != iGraphQlModel) {
            if (this.mGraphQlModel != null) {
                this.mGraphQlModel.asJson().removeJsonUpdateListener(this.mGraphQLModelListener);
            }
            this.mGraphQlModel = iGraphQlModel;
            if (this.mGraphQlModel != null) {
                this.mGraphQlModel.asJson().addJsonUpdateListener(this.mGraphQLModelListener);
            }
        }
    }
}
